#!/usr/bin/env python3
#
# uservice-utils
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import os
import subprocess
import sys
import tempfile


def _run_command(cmd):
    '''Run the command and return the return code or 0 on success.'''

    print('INFO: Executing: {}'.format(' '.join(cmd)))
    try:
        subprocess.check_call(cmd, stderr=subprocess.STDOUT)
    except subprocess.CalledProcessError as e:
        print('ERROR: Calling `{}` failed (with code {})'.format(
            e.cmd, e.returncode))
        return e.returncode
    return 0


def main():
    with tempfile.TemporaryDirectory(prefix='venv') as ve_dir:
        all_cmds = (
            [
                'virtualenv',
                '-p',
                'python3',
                ve_dir,
            ],
            [
                os.path.join(ve_dir, 'bin', 'pip'),
                'install',
                '-r',
                'test_requirements.txt',
            ],
            [
                os.path.join(ve_dir, 'bin', 'python3'),
                'setup.py',
                'test',
            ],
        )
        for cmd in all_cmds:
            ret = _run_command(cmd)
            if ret:
                # A cmd failed, bubble up the return code to the caller
                return ret
    return 0


if __name__ == '__main__':
    sys.exit(main())
